#!/usr/bin/env node

const process = require('process')
const isHelp = process.argv.includes('-h') || process.argv.includes('--help')
const Ora = require('ora')
const Chalk = require('chalk')
const target = process.env.NODE_ENV === 'production' ? 'dist' : 'libs'
const Cli = require(`../${target}`)
const title = '[SCAFFOLDING CLI]'
const spinner = Ora({
  color: 'green',
  text: title
})
const startSpinner = () => {
  if (!isHelp) {
    setImmediate(spinner.start.bind(spinner))
  }
}
const stopSpinner = () => {
  if (!isHelp) {
    setTimeout(spinner.stop.bind(spinner), 1000)
  }
}
const changeSpinnerStyle = color => {
  if (!isHelp) {
    spinner.color = color
  }
}
const log = msg => console.log(Chalk.cyan.bgBlack.bold(msg))
const logError = e => console.log(Chalk.red.bgBlack.bold(e))
const resolve = res => {
  stopSpinner()
  log('CREATING SCAFFOLDING FILE[S] SUCCESSFULLY!')
}
const reject = e => {
  changeSpinnerStyle('red')
  stopSpinner()
  logError(`FAILED TO CREATE SCAFFOLDING FILE[S]! DETAIL: ${e.message}`)
}
const main = async () => {
  if (!isHelp) {
  }
  console.log(Chalk.cyan.bgBlack.bold(title))
  startSpinner()

  return await Cli.run()
    .then(resolve)
    .catch(reject)
}
main()
