const assert = require('assert')
const _ = require('lodash')
const path = require('path')
const util = require('util')
const { promisify } = util
const fs = require('fs')
const CliTest = require('command-line-test')
let test
/**
 *
 */
describe('TEST Scaffolding', () => {
  before(() => {
    test = new CliTest()
    test.exec('cd ../')
  })
  it('GREEN: CASE1', done => {
    test.exec('node bin/index g test --controller --force -- ').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(_.isNull(error), true)
      assert.strictEqual(fs.existsSync(path.resolve('controllers', 'test.js')), true)
      assert.strictEqual(`${stdout}`.includes('SCAFFOLDING DONE'), true)
      done()
    })
  })
  it('GREEN: CASE2', done => {
    test.exec('node bin/index g test --model --force -- ').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(_.isNull(error), true)
      assert.strictEqual(fs.existsSync(path.resolve('models', 'tests.js')), true)
      assert.strictEqual(`${stdout}`.includes('SCAFFOLDING DONE'), true)
      done()
    })
  })
  it('GREEN: CASE3', done => {
    test.exec('node bin/index g test --route --force -- ').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(_.isNull(error), true)
      assert.strictEqual(fs.existsSync(path.resolve('routes', 'test.js')), true)
      assert.strictEqual(`${stdout}`.includes('SCAFFOLDING DONE'), true)
      done()
    })
  })
  it('GREEN: CASE4', done => {
    test.exec('node bin/index g test --schema --force -- ').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(_.isNull(error), true)
      assert.strictEqual(fs.existsSync(path.resolve('schemas', 'test.js')), true)
      assert.strictEqual(`${stdout}`.includes('SCAFFOLDING DONE'), true)
      done()
    })
  })
  it('GREEN: CASE5', done => {
    test.exec('node bin/index --version').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(`${stdout}`.includes(process.env.npm_package_version), true)
      assert.strictEqual(_.isNull(error), true)
      done()
    })
  })
  it('GREEN: CASE6', done => {
    test.exec('node bin/index --help').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(_.isNull(error), true)
      assert.strictEqual(`${stdout}`.includes('[SCAFFOLDING CLI]: SCAFFOLDING'), true)
      done()
    })
  })
  it('GREEN: CASE7', done => {
    test.exec('node bin/index g test --run-all --force -- ').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(_.isNull(error), true)
      assert.strictEqual(`${stdout}`.includes('SCAFFOLDING DONE'), true)
      done()
    })
  })
  it('RED: CASE1', done => {
    test.exec('node bin/index -unknown ').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(_.isError(error), true)
      done()
    })
  })
  it('RED: CASE2', done => {
    test.exec('node bin/index g --route --force -- ').then(res => {
      const { error, stdout } = res
      assert.strictEqual(_.isString(stdout), true)
      assert.strictEqual(_.isError(error), true)
      done()
    })
  })
  after(async () => {
    const rimraf = require('rimraf')
    const options = {
      maxBusyTries: 3,
      disableGlob: false
    }
    await promisify(rimraf)(path.resolve('controllers', 'test.js'), options)
    await promisify(rimraf)(path.resolve('models', 'tests.js'), options)
    await promisify(rimraf)(path.resolve('routes', 'test.js'), options)
    await promisify(rimraf)(path.resolve('schemas', 'test.js'), options)
  })
})
